# catfishq
Takes paths to an arbritary number of zipped and unzipped FASTQ files and/or folders containing zipped or unzipped FASTQ files, concatenates them and prints them to standard out (default) or an unzipped output file.

Supported file extensions are: `'*.fastq', '*.fastq.gz', '*.fasta', '*.fasta.gz', '*.fa', '*.fa.gz', '*.fq', '*.fq.gz'`

# Install
``` bash
pip install catfishq
```

# Example
```bash
$ catfishq -r test/
```


